import pytest
import pyoshub.pyoshub as pyoshub
import os
from dotenv import load_dotenv

load_dotenv()


@pytest.fixture(scope='module')
def vcr_config():
    return {
        # Replace the Authorization request header with "DUMMY" in cassettes
        "filter_headers": [
            ('authorization', 'HIDDEN')],
        "record_mode": 'new'
    }


@pytest.mark.vcr()
class Test_get_facility_processing_types:
    def test_get_facility_processing_types(self):
        osh_api = pyoshub.OSH_API(
            url=os.environ["TEST_OSH_URL"],
            token=os.environ["TEST_OSH_TOKEN"],
            check_token=True)
        result = osh_api.get_facility_processing_types()
        assert (len(result) == 137)
        assert (result == [
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Assembly'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Cut & Sew'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Cutting'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Embellishment'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Embroidery'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Final Product Assembly'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Finished Goods'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Ironing'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Knit Composite'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Knitwear Assembly'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Linking'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Making up'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Manufacturing'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Marker Making'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Molding'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Packaging'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Pattern Grading'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Pleating'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Product Finishing'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Ready Made Garment'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Sample Making'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Seam taping'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Sewing'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Steaming'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Stitching'},
            {'facility_type': 'Final Product Assembly', 'processing_type': 'Tailoring'},
            {'facility_type': 'Office / HQ', 'processing_type': 'Headquarters'},
            {'facility_type': 'Office / HQ', 'processing_type': 'No processing'},
            {'facility_type': 'Office / HQ', 'processing_type': 'Office'},
            {'facility_type': 'Office / HQ', 'processing_type': 'Office / HQ'},
            {'facility_type': 'Office / HQ', 'processing_type': 'Sourcing Agent'},
            {'facility_type': 'Office / HQ', 'processing_type': 'Trading'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Batch Dyeing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Coating'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Continuous dyeing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Direct Digital Ink Printing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Dyeing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Fabric All Over Print'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Fabric Chemical Finishing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Fiber Dye'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Finishing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Flat Screen Printing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Garment Dyeing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Garment Finishing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Garment Place Print'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Garment Wash'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Hand Dye'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Laundering'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Laundry'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Pre-treatment'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Printing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Printing, Product Dyeing and Laundering'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Product Dyeing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Rotary Printing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Screen Printing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Spray Dye'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Sublimation'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Textile Chemical Finishing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Textile Dyeing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Textile Mechanical Finishing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Textile Printing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Tye Dye'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Washing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Wet Processing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Wet roller printing'},
            {'facility_type': 'Printing, Product Dyeing and Laundering', 'processing_type': 'Yarn Dyeing'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Biological Recycling'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Boiling'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Breeding'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Chemical Recycling'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Chemical Synthesis'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Collecting'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Concentrating'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Disassembly'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Down Processing'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Dry Spinning'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Extrusion'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Ginning'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Hatchery'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Mechanical Recycling'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Melt Spinning'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Preparation'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Preparatory'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Processing Site'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Pulp making'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Raw Material Processing or Production'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Retting'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Scouring'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Shredding'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Slaughterhouse'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Slaughtering'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Sorting'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Spinning'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Standardization / Chemical finishing'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Synthetic Leather Production'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Tannery'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Tanning'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Textile Recycling'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Top making'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Twisting/Texturizing Facility'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Wet Spinning'},
            {'facility_type': 'Raw Material Processing or Production', 'processing_type': 'Yarn spinning'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Blending'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Bonding'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Buffing'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Circular Knitting'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Components'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Doubling'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Embellishment'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Embossing'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Embroidery'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Fabric mill'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Flat Knit'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Fusing'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Garment Accessories manufacturing'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Knitting'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Knitting Seamless'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Knitting V Bed'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Knitting Warp'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Lace Knitting'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Laminating'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Material Creation'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Material Production'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Mill'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Nonwoven Processing'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Nonwoven manufacturing'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Painting'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Pelletizing'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Pressing'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Spraying'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Straight Bar Knitting'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Textile Mill'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Textile or Material Production'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Weaving'},
            {'facility_type': 'Textile or Material Production', 'processing_type': 'Welding'},
            {'facility_type': 'Warehousing / Distribution', 'processing_type': 'Packing'},
            {'facility_type': 'Warehousing / Distribution', 'processing_type': 'Warehousing / Distribution'}
        ])
